==> eiffelstudio-16.05.tar: F_code/C1/in16.c <==
/*
 * Code for class INI_SCANNER_STATE_POOL
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in16.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INI_SCANNER_STATE_POOL}.make */
void F20_170 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("make", 19, Current, 1, 0, 196);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {806,1258,1029,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F807_6236(RTCW(tr1), ((EIF_INTEGER_32) 3L));
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	F300_3613(RTCW(loc1));
	RTHOOK(3);
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {INI_SCANNER_STATE_POOL}.state */
EIF_REFERENCE F20_171 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,Current);
	RTLR(4,Result);
	RTLIU(5);
	
	RTEAA("state", 19, Current, 1, 1, 197);
	RTGC;
	RTHOOK(1);
	tr1 = (EIF_REFERENCE) eif_builtin_ANY_generating_type (arg1);
	loc1 = F1045_8327(RTCW(tr1));
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = F807_6240(RTCW(tr1), loc1);
	RTHOOK(3);
	if ((EIF_BOOLEAN)(Result == NULL)) {
		RTHOOK(4);
		tr1 = RTLNTY2(eif_new_type(1262, 0x00), 0x00);
		if (RTEQ(arg1, tr1)) {
			RTHOOK(5);
			tr1 = RTLNS(eif_new_type(1262, 0x00).id, 1262, _OBJSIZ_2_0_0_0_0_0_0_0_);
			Result = (EIF_REFERENCE) tr1;
		} else {
			RTHOOK(6);
			tr1 = RTLNTY2(eif_new_type(1260, 0x00), 0x00);
			if (RTEQ(arg1, tr1)) {
				RTHOOK(7);
				tr1 = RTLNS(eif_new_type(1260, 0x00).id, 1260, _OBJSIZ_2_0_0_0_0_0_0_0_);
				Result = (EIF_REFERENCE) tr1;
			} else {
				RTHOOK(8);
				tr1 = RTLNTY2(eif_new_type(1261, 0x00), 0x00);
				if (RTEQ(arg1, tr1)) {
					RTHOOK(9);
					tr1 = RTLNS(eif_new_type(1261, 0x00).id, 1261, _OBJSIZ_2_0_0_0_0_0_0_0_);
					Result = (EIF_REFERENCE) tr1;
				} else {
					RTHOOK(10);
					tr1 = RTLNTY2(eif_new_type(1259, 0x00), 0x00);
					if (RTEQ(arg1, tr1)) {
						RTHOOK(11);
						tr1 = RTLNS(eif_new_type(1259, 0x00).id, 1259, _OBJSIZ_2_0_0_0_0_0_0_0_);
						Result = (EIF_REFERENCE) tr1;
					}
				}
			}
		}
		RTHOOK(12);
		tr1 = *(EIF_REFERENCE *)(Current);
		F807_6283(RTCW(tr1), Result, loc1);
	}
	RTHOOK(13);
	RTLE;
	RTEE;
	return Result;
}

/* {INI_SCANNER_STATE_POOL}.state_pool */
EIF_REFERENCE F20_172 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


void EIF_Minit16 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C1/in16.c <==
/*
 * Code for class INI_SCANNER_STATE_POOL
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in16.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INI_SCANNER_STATE_POOL}.make */
void F20_170 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("make", 19, Current, 1, 0, 195);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {823,1267,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F816_6563(RTCW(tr1), ((EIF_INTEGER_32) 3L));
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	F288_3445(RTCW(loc1));
	RTHOOK(3);
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {INI_SCANNER_STATE_POOL}.state */
EIF_REFERENCE F20_171 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,Result);
	RTLIU(5);
	
	RTEAA("state", 19, Current, 1, 1, 196);
	RTGC;
	RTHOOK(1);
	loc1 = (EIF_REFERENCE) eif_builtin_ANY_generating_type (arg1);
	loc1 = F1060_8678(RTCW(loc1));
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = F816_6567(RTCW(tr1), loc1);
	RTHOOK(3);
	if ((EIF_BOOLEAN)(Result == NULL)) {
		RTHOOK(4);
		tr1 = RTLNTY2(eif_new_type(1271, 0x00), 0x00);
		if (RTEQ(arg1, tr1)) {
			RTHOOK(5);
			tr1 = RTLNS(eif_new_type(1271, 0x00).id, 1271, _OBJSIZ_2_0_0_0_0_0_0_0_);
			Result = (EIF_REFERENCE) tr1;
		} else {
			RTHOOK(6);
			tr1 = RTLNTY2(eif_new_type(1270, 0x00), 0x00);
			if (RTEQ(arg1, tr1)) {
				RTHOOK(7);
				tr1 = RTLNS(eif_new_type(1270, 0x00).id, 1270, _OBJSIZ_2_0_0_0_0_0_0_0_);
				Result = (EIF_REFERENCE) tr1;
			} else {
				RTHOOK(8);
				tr1 = RTLNTY2(eif_new_type(1268, 0x00), 0x00);
				if (RTEQ(arg1, tr1)) {
					RTHOOK(9);
					tr1 = RTLNS(eif_new_type(1268, 0x00).id, 1268, _OBJSIZ_2_0_0_0_0_0_0_0_);
					Result = (EIF_REFERENCE) tr1;
				} else {
					RTHOOK(10);
					tr1 = RTLNTY2(eif_new_type(1269, 0x00), 0x00);
					if (RTEQ(arg1, tr1)) {
						RTHOOK(11);
						tr1 = RTLNS(eif_new_type(1269, 0x00).id, 1269, _OBJSIZ_2_0_0_0_0_0_0_0_);
						Result = (EIF_REFERENCE) tr1;
					} else {
						RTHOOK(12);
						RTCT0("valid_type_from_precondition", EX_CHECK);
							RTCF0;
					}
				}
			}
		}
		RTHOOK(13);
		tr1 = *(EIF_REFERENCE *)(Current);
		F816_6610(RTCW(tr1), Result, loc1);
	}
	RTHOOK(14);
	RTLE;
	RTEE;
	return Result;
}

/* {INI_SCANNER_STATE_POOL}.state_pool */
EIF_REFERENCE F20_172 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


void EIF_Minit16 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
